# Welcome to pyfracval's documentation!

<img src="_static/logo.png" alt="PyFracVAL Logo" width="50%">

PyFracVAL generates fractal-like aggregates... (add a brief description)

```{toctree}
:maxdepth: 2
:caption: Contents:

installation
usage
references
```
